==> sawmill6.4b3_crypt_src.tar.gz: sawmill-6.4b3/S07aa74af7efa0bc592378f54fe5f8ff3.cpp <==
//
// Sawmill Source Code
// 
// This source code is the intellectual property of Flowerfire,
// and is protected by federal trade secret laws.  Do not
// redistribute, modify, or use this source code, except to compile
// it, without the express written consent of Flowerfire.
//
// For more information, see http://www.sawmill.net/trade_secret.html
//
// The trial and full commercial licenses for Sawmill allow you
// to use the program, and to compile it from this source code,
// but you are not permitted to look at this source code.  Please
// do not attempt to use this source code for any purpose other 
// then compilation!



















































 
#include "S76eaa083f88fdd66f6f3f7ac1cd91f27.h"

#include "S57eed6fb2a8ce5b9f949ceebffa654b5.h"

#include "S18fff9cb5ec66ea1b3998c0c6f504bdd.h"
 
#ifdef macintosh
 
#pragma Sdcf15d3851e1b8c3d02afa9e565936b4 off
 
#endif
  void S553a1060e9afd65c7c2be3041f95d200(Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179) 
{  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, new Sbe3e989ada99c227c97c9af8c198bf6f(true, 
false, S099fb995346f31c749f6e40db0f395e3, S10249d8f3b79a36b96ceb5e39d010f7f, NULL, "page_header", "ph", 
new Sa66884641c1eee0d1eab73a89af79cfc(S4d682ec4eed27c53849758bc13b6e179, "")));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, true, S099fb995346f31c749f6e40db0f395e3, S10249d8f3b79a36b96ceb5e39d010f7f, 
NULL, "page_header_file", "phf", new Sd0ab4849fc91062931b627de26bed172(S4d682ec4eed27c53849758bc13b6e179, 
"")));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, new Sbe3e989ada99c227c97c9af8c198bf6f(true, 
false, S099fb995346f31c749f6e40db0f395e3, S10249d8f3b79a36b96ceb5e39d010f7f, NULL, "page_footer", "pf", 
new Sa66884641c1eee0d1eab73a89af79cfc(S4d682ec4eed27c53849758bc13b6e179, "")));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, true, S099fb995346f31c749f6e40db0f395e3, S10249d8f3b79a36b96ceb5e39d010f7f, 
NULL, "page_footer_file", "pff", new Sd0ab4849fc91062931b627de26bed172(S4d682ec4eed27c53849758bc13b6e179, 
"")));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, new Sbe3e989ada99c227c97c9af8c198bf6f(true, 
true, S099fb995346f31c749f6e40db0f395e3, S10249d8f3b79a36b96ceb5e39d010f7f, NULL, "page_frame_command", 
"pfc", new Sa66884641c1eee0d1eab73a89af79cfc(S4d682ec4eed27c53849758bc13b6e179, "")));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, S099fb995346f31c749f6e40db0f395e3, S10249d8f3b79a36b96ceb5e39d010f7f, 
NULL, "preprocess_headers_and_footers", "phaf", new S34c8bc3f549bc1db617d4ed83a8481b4(false)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Sf8b0b924ebd7046dbfa85a856e4682c8, S5f5c74b2be2b3cdb533fed1989d12a7c, 
NULL, "statistics_page_background_color", "spbc", new S58aff0477f38707b97c84a6899d13624(0, 0, 255), 
new S58aff0477f38707b97c84a6899d13624(0, 0, 255), new S58aff0477f38707b97c84a6899d13624(0, 0, 255))); 
 S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, new Sbe3e989ada99c227c97c9af8c198bf6f(true, 
false, Sf8b0b924ebd7046dbfa85a856e4682c8, S5f5c74b2be2b3cdb533fed1989d12a7c, NULL, "view_sidebar_background_color", 
"vsbc", new S58aff0477f38707b97c84a6899d13624(0, 0, 255), new S58aff0477f38707b97c84a6899d13624(0, 0, 
255), new S58aff0477f38707b97c84a6899d13624(0, 0, 255)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Sf8b0b924ebd7046dbfa85a856e4682c8, S6e140e2f2221b90042fef432e6d282eb, 
NULL, "hidden_views_url", "hvu", new Sa66884641c1eee0d1eab73a89af79cfc(S4d682ec4eed27c53849758bc13b6e179, 
""))); }

==> sawmill6.5b3_crypt_src.tar.gz: sawmill-6.5b3/S07aa74af7efa0bc592378f54fe5f8ff3.cpp <==
//
// Sawmill Source Code
// 
// This source code is the intellectual property of Flowerfire,
// and is protected by federal trade secret laws.  Do not
// redistribute, modify, or use this source code, except to compile
// it, without the express written consent of Flowerfire.
//
// For more information, see http://www.sawmill.net/trade_secret.html
//
// The trial and full commercial licenses for Sawmill allow you
// to use the program, and to compile it from this source code,
// but you are not permitted to look at this source code.  Please
// do not attempt to use this source code for any purpose other 
// than compilation!



















































 
#include "S76eaa083f88fdd66f6f3f7ac1cd91f27.h"

#include "S57eed6fb2a8ce5b9f949ceebffa654b5.h"

#include "S18fff9cb5ec66ea1b3998c0c6f504bdd.h"
 
#ifdef macintosh
 
#pragma Sdcf15d3851e1b8c3d02afa9e565936b4 off
 
#endif
  void S553a1060e9afd65c7c2be3041f95d200(Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179) 
{  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, new Sbe3e989ada99c227c97c9af8c198bf6f(true, 
false, S099fb995346f31c749f6e40db0f395e3, S10249d8f3b79a36b96ceb5e39d010f7f, NULL, "page_header", "ph", 
new Sa66884641c1eee0d1eab73a89af79cfc(S4d682ec4eed27c53849758bc13b6e179, "")));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, true, S099fb995346f31c749f6e40db0f395e3, S10249d8f3b79a36b96ceb5e39d010f7f, 
NULL, "page_header_file", "phf", new Sd0ab4849fc91062931b627de26bed172(S4d682ec4eed27c53849758bc13b6e179, 
"")));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, new Sbe3e989ada99c227c97c9af8c198bf6f(true, 
false, S099fb995346f31c749f6e40db0f395e3, S10249d8f3b79a36b96ceb5e39d010f7f, NULL, "page_footer", "pf", 
new Sa66884641c1eee0d1eab73a89af79cfc(S4d682ec4eed27c53849758bc13b6e179, "")));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, true, S099fb995346f31c749f6e40db0f395e3, S10249d8f3b79a36b96ceb5e39d010f7f, 
NULL, "page_footer_file", "pff", new Sd0ab4849fc91062931b627de26bed172(S4d682ec4eed27c53849758bc13b6e179, 
"")));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, new Sbe3e989ada99c227c97c9af8c198bf6f(true, 
true, S099fb995346f31c749f6e40db0f395e3, S10249d8f3b79a36b96ceb5e39d010f7f, NULL, "page_frame_command", 
"pfc", new Sa66884641c1eee0d1eab73a89af79cfc(S4d682ec4eed27c53849758bc13b6e179, "")));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, S099fb995346f31c749f6e40db0f395e3, S10249d8f3b79a36b96ceb5e39d010f7f, 
NULL, "sub_view_header", "svh", new Sa66884641c1eee0d1eab73a89af79cfc(S4d682ec4eed27c53849758bc13b6e179, 
"")));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, new Sbe3e989ada99c227c97c9af8c198bf6f(true, 
false, S099fb995346f31c749f6e40db0f395e3, S10249d8f3b79a36b96ceb5e39d010f7f, NULL, "sub_view_footer", 
"svf", new Sa66884641c1eee0d1eab73a89af79cfc(S4d682ec4eed27c53849758bc13b6e179, "")));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, S099fb995346f31c749f6e40db0f395e3, S10249d8f3b79a36b96ceb5e39d010f7f, 
NULL, "preprocess_headers_and_footers", "phaf", new S34c8bc3f549bc1db617d4ed83a8481b4(false)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Sf8b0b924ebd7046dbfa85a856e4682c8, S5f5c74b2be2b3cdb533fed1989d12a7c, 
NULL, "statistics_page_background_color", "spbc", new S58aff0477f38707b97c84a6899d13624(0, 0, 255), 
new S58aff0477f38707b97c84a6899d13624(0, 0, 255), new S58aff0477f38707b97c84a6899d13624(0, 0, 255))); 
 S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, new Sbe3e989ada99c227c97c9af8c198bf6f(true, 
false, Sf8b0b924ebd7046dbfa85a856e4682c8, S5f5c74b2be2b3cdb533fed1989d12a7c, NULL, "view_sidebar_background_color", 
"vsbc", new S58aff0477f38707b97c84a6899d13624(0, 0, 255), new S58aff0477f38707b97c84a6899d13624(0, 0, 
255), new S58aff0477f38707b97c84a6899d13624(0, 0, 255)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Sf8b0b924ebd7046dbfa85a856e4682c8, S6e140e2f2221b90042fef432e6d282eb, 
NULL, "hidden_views_url", "hvu", new Sa66884641c1eee0d1eab73a89af79cfc(S4d682ec4eed27c53849758bc13b6e179, 
""))); }
